@@ -181,8 +181,10 @@ def check_parameter_df(
 
     # nominal value is generally optional, but required if any for any
     #  parameter estimate != 1
-    non_estimated_par_ids = list(df.index[(df[ESTIMATE] != 1)
-                                          | (df[ESTIMATE] != '1')])
+    non_estimated_par_ids = list(
+        df.index[(df[ESTIMATE] != 1) | (
+            pd.api.types.is_string_dtype(df[ESTIMATE])
+            and df[ESTIMATE] != '1')])
     if non_estimated_par_ids:
         if NOMINAL_VALUE not in df:
             raise AssertionError("Parameter table contains parameters "
